const fs = require('fs')
const http = require('http')
const url = require('url')
const path = require('path')

const port = 8000

const mimes = {
  '.js': 'text/javascript',
  '.css': 'text/css',
  '.html': 'text/html'
}

const server = http.createServer(function (request, response) {
  const pathname = url.parse(request.url).pathname

  let filename = path.join(process.cwd(), pathname)
  
  // if the requested path has no file extension, assume it's a directory
  // caution: if you are shipping an API, this is the wrong thing to do  
  if (!path.extname(filename)) {
    filename = `${filename}/index.html`
  }

  console.log(filename)
  
  fs.exists(filename, function (exists) {
    if (!exists) {
      response.writeHead(404, {'Content-Type': 'text/plain'})
      response.write('404 Not Found')
      response.end()
      return
    }

    response.writeHead(200, {
      'Content-Type': mimes[path.extname(filename)]
    })
    
    fs.createReadStream(filename, {
      'flags': 'r',
      'encoding': 'binary',
      'mode': 0666,
      'bufferSize': 4 * 1024
    }).addListener('data', function (chunk) {
      response.write(chunk, 'binary')
    }).addListener('close', function() {
      response.end()
    })
  })
})

server.listen(port)
console.log(`Listening on ${port}`)