export function querystring (str) {
  const arr = (str || window.location.search).slice(1).split('&')
  const res = {}

  arr.forEach(function (item) {
    if (item === '') return

    const [key, value] = item.split('=')
    res[key] = value ? decodeURIComponent(value) : undefined
  })

  return res
}

const getCookieRegex = /[-.+*]/g

export function getCookie (key) {
  return !key ? undefined : decodeURIComponent(document.cookie.replace(
    new RegExp(`(?:(?:^|.*;)\\s*${encodeURIComponent(key)
      .replace(getCookieRegex, '\\$&')}\\s*\\=\\s*([^;]*).*$)|^.*$`), '$1')
  ) || undefined
}

const loaded = {}

export function loadScript (props) {
  const { el, src, onload, id, innerHTML, link, style } = props

  // script has already been loaded
  if (loaded[src] && onload) {
    return onload()
  }

  const script = document.createElement(link ? 'link' : style ? 'style' : 'script')
  const e = el || document.head

  if (link) {
    script.rel = 'stylesheet'
    script.type = ' text/css'
    script.href = src
    e.appendChild(script)
    return
  }

  script.async = (props.async === undefined) ? true : props.async

  script.onload = function load () {
    loaded[src] = true
    if (onload) onload()
  }

  if (id) script.id = id
  if (src) script.src = src
  if (innerHTML) script.innerHTML = innerHTML

  e.appendChild(script)
}
